@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux/GNU
-    Copyright (C) 2004-2019 Antonio Diaz Diaz.
+    Copyright (C) 2004-2020 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@
 namespace {
 
 const char * const program_name = "adcd";
-const char * const program_year = "2019";
-const char * invocation_name = 0;
+const char * const program_year = "2020";
+const char * invocation_name = program_name;		// default value
 
 
 void show_help()
@@ -134,7 +134,7 @@ int main( const int argc, const char * argv[] )
   int step = 0, track = 1, volume = 0;
   bool open_tray = false, close_tray = false;
   bool info = false, pause = false, play = false, stop = false;
-  invocation_name = argv[0];
+  if( argc > 0 ) invocation_name = argv[0];
 
   const Arg_parser::Option options[] =
     {
